var class_ogre_1_1_scene_manager =
[
    [ "Listener", "class_ogre_1_1_scene_manager_1_1_listener.html", "class_ogre_1_1_scene_manager_1_1_listener" ],
    [ "RenderContext", "struct_ogre_1_1_scene_manager_1_1_render_context.html", "struct_ogre_1_1_scene_manager_1_1_render_context" ],
    [ "SceneMgrQueuedRenderableVisitor", "class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html", "class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor" ],
    [ "SkyBoxGenParameters", "struct_ogre_1_1_scene_manager_1_1_sky_box_gen_parameters.html", "struct_ogre_1_1_scene_manager_1_1_sky_box_gen_parameters" ],
    [ "SkyDomeGenParameters", "struct_ogre_1_1_scene_manager_1_1_sky_dome_gen_parameters.html", "struct_ogre_1_1_scene_manager_1_1_sky_dome_gen_parameters" ],
    [ "SkyPlaneGenParameters", "struct_ogre_1_1_scene_manager_1_1_sky_plane_gen_parameters.html", "struct_ogre_1_1_scene_manager_1_1_sky_plane_gen_parameters" ],
    [ "CameraList", "class_ogre_1_1_scene_manager.html#a361c61a0f17ac50c8fd49bc0dd3ff622", null ],
    [ "MovableObjectMap", "class_ogre_1_1_scene_manager.html#a317d0ca0b29d739ed54b4422f850b629", null ],
    [ "StaticGeometryMap", "class_ogre_1_1_scene_manager.html#a0cd89dcbd8d830a2a3c03dac27f42c44", null ],
    [ "CameraIterator", "class_ogre_1_1_scene_manager.html#a22fcb8a9ddb7efe79d053a975a685111", null ],
    [ "AnimationIterator", "class_ogre_1_1_scene_manager.html#a3a720414f68274bb9c5026911e27135d", null ],
    [ "MovableObjectIterator", "class_ogre_1_1_scene_manager.html#a4249682ae2a69255ed225383d930aec1", null ],
    [ "QueryTypeMask", "class_ogre_1_1_scene_manager.html#a6d604937ee8d07e24f99ba5cdf64638a", [
      [ "WORLD_GEOMETRY_TYPE_MASK", "class_ogre_1_1_scene_manager.html#a6d604937ee8d07e24f99ba5cdf64638aabf31f2e39287202aaf433b4f4eca2ba9", null ],
      [ "ENTITY_TYPE_MASK", "class_ogre_1_1_scene_manager.html#a6d604937ee8d07e24f99ba5cdf64638aa7b1c9dfb3ee3bf4224e445b9417193e0", null ],
      [ "FX_TYPE_MASK", "class_ogre_1_1_scene_manager.html#a6d604937ee8d07e24f99ba5cdf64638aa58f7504dd6f56b3e699c552e3a5edb55", null ],
      [ "STATICGEOMETRY_TYPE_MASK", "class_ogre_1_1_scene_manager.html#a6d604937ee8d07e24f99ba5cdf64638aa1a7c8356b383826010f83e88f89ae258", null ],
      [ "LIGHT_TYPE_MASK", "class_ogre_1_1_scene_manager.html#a6d604937ee8d07e24f99ba5cdf64638aa8e038bbc4c20e0b165a93456aceccac1", null ],
      [ "FRUSTUM_TYPE_MASK", "class_ogre_1_1_scene_manager.html#a6d604937ee8d07e24f99ba5cdf64638aafa4ca767da4b4d17cb62d1f68a5dd614", null ],
      [ "USER_TYPE_MASK_LIMIT", "class_ogre_1_1_scene_manager.html#a6d604937ee8d07e24f99ba5cdf64638aa5c2b2136e910fcade606b7ff99359acc", null ]
    ] ],
    [ "IlluminationRenderStage", "class_ogre_1_1_scene_manager.html#a51db39cc4fa15b28086a1793d42fc827", [
      [ "IRS_NONE", "class_ogre_1_1_scene_manager.html#a51db39cc4fa15b28086a1793d42fc827a8fd3e7fb8fab382a9d29e6e081ae556a", null ],
      [ "IRS_RENDER_TO_TEXTURE", "class_ogre_1_1_scene_manager.html#a51db39cc4fa15b28086a1793d42fc827a8f99da7404ae8c16199dde8d34367b1a", null ],
      [ "IRS_RENDER_RECEIVER_PASS", "class_ogre_1_1_scene_manager.html#a51db39cc4fa15b28086a1793d42fc827a0e1792a8ff0d3d19f121818e7028e846", null ]
    ] ],
    [ "SpecialCaseRenderQueueMode", "class_ogre_1_1_scene_manager.html#a6aa3039230bf91b09b8587dba0c482c6", [
      [ "SCRQM_INCLUDE", "class_ogre_1_1_scene_manager.html#a6aa3039230bf91b09b8587dba0c482c6a4f5291417680ce7d1715b7aef50869a7", null ],
      [ "SCRQM_EXCLUDE", "class_ogre_1_1_scene_manager.html#a6aa3039230bf91b09b8587dba0c482c6acc6b7e38cc21cf87a29e17177dc1a0b3", null ]
    ] ],
    [ "SceneManager", "class_ogre_1_1_scene_manager.html#a09e76a674bc69c610fb49acd3da76cf1", null ],
    [ "~SceneManager", "class_ogre_1_1_scene_manager.html#a6c8b9108b44339a321bc69b25a0c0a1a", null ],
    [ "_pauseRendering", "class_ogre_1_1_scene_manager.html#a5c9816798bda78389efc4f071051c739", null ],
    [ "_resumeRendering", "class_ogre_1_1_scene_manager.html#a794e03ea25dd798346414c1dba31337d", null ],
    [ "usePerRenderableLights", "class_ogre_1_1_scene_manager.html#abea7f1022bf24e920d9e0771314bda9c", null ],
    [ "hasPerRenderableLights", "class_ogre_1_1_scene_manager.html#a053df07afa2037d378450e2063b45560", null ],
    [ "OGRE_MUTEX", "class_ogre_1_1_scene_manager.html#a9b10b7fef2893e75acc083415df70446", null ],
    [ "getName", "class_ogre_1_1_scene_manager.html#a8d29d1e2d954090ce2fba768b7f30c02", null ],
    [ "getTypeName", "class_ogre_1_1_scene_manager.html#a2f139de7c96a237754f075dbca80670e", null ],
    [ "createCamera", "class_ogre_1_1_scene_manager.html#a9a394daa05374d05e4e378f540418c1f", null ],
    [ "getCamera", "class_ogre_1_1_scene_manager.html#a5d045c10d23adb73e03751505beb346a", null ],
    [ "hasCamera", "class_ogre_1_1_scene_manager.html#a3339b949a5f7927d80b48fb19044e1cb", null ],
    [ "destroyCamera", "class_ogre_1_1_scene_manager.html#a2038ca3f3b95a14152f26c6933f1a179", null ],
    [ "destroyCamera", "class_ogre_1_1_scene_manager.html#af0c316e631cbbbb85137a328aee28b7c", null ],
    [ "destroyAllCameras", "class_ogre_1_1_scene_manager.html#a710197d0688d6b3876984d595bdfa6ba", null ],
    [ "setCameraRelativeRendering", "class_ogre_1_1_scene_manager.html#af24677a56a91713c40c3bdb9025da38d", null ],
    [ "getCameraRelativeRendering", "class_ogre_1_1_scene_manager.html#acbf7af4f58966c776091f73c383ec2ae", null ],
    [ "getCameraIterator", "class_ogre_1_1_scene_manager.html#a02d7d29cc4bc8ee4cbe40d16a984291c", null ],
    [ "getCameras", "class_ogre_1_1_scene_manager.html#ab7d0636b79f0ae7cc2cae4b92c664cc6", null ],
    [ "createLight", "class_ogre_1_1_scene_manager.html#a829e11cca3dfaf8142578930e1da6844", null ],
    [ "createLight", "class_ogre_1_1_scene_manager.html#a1eb9f7111a00759f64908d41b31a2d5f", null ],
    [ "createLight", "class_ogre_1_1_scene_manager.html#a7399c836bf57186f171f4eb456c7fe4d", null ],
    [ "createLight", "class_ogre_1_1_scene_manager.html#a1e1dbdd1006ff358097f57292e1b8964", null ],
    [ "getLight", "class_ogre_1_1_scene_manager.html#affcefaa227a8b0de8dc800e53a4ac10f", null ],
    [ "hasLight", "class_ogre_1_1_scene_manager.html#a55d38f8da01e689b2d65e2b71ad9a9b0", null ],
    [ "getLightClippingPlanes", "class_ogre_1_1_scene_manager.html#a23ec8811a1b1a40b67c9a01bb97cd4af", null ],
    [ "getLightScissorRect", "class_ogre_1_1_scene_manager.html#afb5bb25f8bec41a2a0cf9a6479bb309e", null ],
    [ "invalidatePerFrameScissorRectCache", "class_ogre_1_1_scene_manager.html#ace3cf4289a6b9ce4d5547d25153a84e2", null ],
    [ "destroyLight", "class_ogre_1_1_scene_manager.html#aef6d26cb64e7a1984ebff9b56c45c6e5", null ],
    [ "destroyLight", "class_ogre_1_1_scene_manager.html#ae0f5af4dee25887e0726cb28fd49f722", null ],
    [ "destroyAllLights", "class_ogre_1_1_scene_manager.html#a723da9119c26f5022e3a2818611e9aa0", null ],
    [ "_notifyLightsDirty", "class_ogre_1_1_scene_manager.html#af215cf844dc1f3a2cb67b2149938847d", null ],
    [ "_getLightsDirtyCounter", "class_ogre_1_1_scene_manager.html#a56f24ca2f117f45d6078e54d63de235c", null ],
    [ "_getLightsAffectingFrustum", "class_ogre_1_1_scene_manager.html#aacb4f28f6f9ae731040c9d664da7d6ce", null ],
    [ "_populateLightList", "class_ogre_1_1_scene_manager.html#ad7330d1bfd3ed9700a1716151acbead3", null ],
    [ "_populateLightList", "class_ogre_1_1_scene_manager.html#ac6e42c947472bf09620ef974c3ac26a5", null ],
    [ "createSceneNode", "class_ogre_1_1_scene_manager.html#abb1b2745f8b8537434dbb1e9a8b4c020", null ],
    [ "createSceneNode", "class_ogre_1_1_scene_manager.html#a4f17d2305cd0fc3e177d9264b9beda52", null ],
    [ "destroySceneNode", "class_ogre_1_1_scene_manager.html#aa613e5ffb08b95a90644a61ac10c9b5c", null ],
    [ "destroySceneNode", "class_ogre_1_1_scene_manager.html#a813346e505716ae5d24f714cfc4a5069", null ],
    [ "getRootSceneNode", "class_ogre_1_1_scene_manager.html#a7924f5a9ac983d29a5876d633f8a971d", null ],
    [ "getSceneNode", "class_ogre_1_1_scene_manager.html#ad9facb91c8cacec792f0952bf1102f9e", null ],
    [ "hasSceneNode", "class_ogre_1_1_scene_manager.html#a15bd8a3d9cb33ddaf37598af5c2f534f", null ],
    [ "setDisplaySceneNodes", "class_ogre_1_1_scene_manager.html#a589b3eb241b2531097d7ed67e716d420", null ],
    [ "getDisplaySceneNodes", "class_ogre_1_1_scene_manager.html#a7b0f316813a3291964abd93ca2372f3d", null ],
    [ "showBoundingBoxes", "class_ogre_1_1_scene_manager.html#aabb31522f577a7ebc1ecade779d056c9", null ],
    [ "getShowBoundingBoxes", "class_ogre_1_1_scene_manager.html#a57bca9b27045ef0acc9d6cfe5f2668dd", null ],
    [ "getDebugDrawer", "class_ogre_1_1_scene_manager.html#a31b3f99bc8971694da2c264ba63ac993", null ],
    [ "createEntity", "class_ogre_1_1_scene_manager.html#a7bb6387adbaaac0ff9119e3a85931505", null ],
    [ "createEntity", "class_ogre_1_1_scene_manager.html#a56882cf297909d38cb48b037dcbbfbd5", null ],
    [ "createEntity", "class_ogre_1_1_scene_manager.html#a2a3ac25a1d1639c641f5f09b7744ca70", null ],
    [ "createEntity", "class_ogre_1_1_scene_manager.html#af0c41f6c8b2bb2616e0e9b08d14231bf", null ],
    [ "getEntity", "class_ogre_1_1_scene_manager.html#a5f5320728d8846ebe7ced3b972d37520", null ],
    [ "hasEntity", "class_ogre_1_1_scene_manager.html#a4a672aaeb3ede6c03e1b072d51e21b7a", null ],
    [ "destroyEntity", "class_ogre_1_1_scene_manager.html#adb544a5d5477ef91ef683e4ad5e7a39f", null ],
    [ "destroyEntity", "class_ogre_1_1_scene_manager.html#a59347bd0277c99dc2291965053aed4c6", null ],
    [ "destroyAllEntities", "class_ogre_1_1_scene_manager.html#a8db7412fbb04789eb885c4d503614c0d", null ],
    [ "createManualObject", "class_ogre_1_1_scene_manager.html#ae8fffdc72f339e58be36ba97306cb432", null ],
    [ "createManualObject", "class_ogre_1_1_scene_manager.html#a81e0a45199422dd2e4f4ffd49fde482e", null ],
    [ "getManualObject", "class_ogre_1_1_scene_manager.html#a178db99889f05c98faae547f7c046c45", null ],
    [ "hasManualObject", "class_ogre_1_1_scene_manager.html#a4b9ad74ecd97a52ed3ad567703d30de6", null ],
    [ "destroyManualObject", "class_ogre_1_1_scene_manager.html#af43ffe9afd9bba932fd51cb02496405f", null ],
    [ "destroyManualObject", "class_ogre_1_1_scene_manager.html#a4718aa3c21b3569eb8772a1abb1af74d", null ],
    [ "destroyAllManualObjects", "class_ogre_1_1_scene_manager.html#ae4e9873e472d78e7595adc3cbbad643a", null ],
    [ "createScreenSpaceRect", "class_ogre_1_1_scene_manager.html#ac52887c4c70b39dcaaab5f0785d4b43b", null ],
    [ "createScreenSpaceRect", "class_ogre_1_1_scene_manager.html#a20bb0ae12fdb213126aa5ee06be29d62", null ],
    [ "hasScreenSpaceRect", "class_ogre_1_1_scene_manager.html#a7e237914603510f73098315612feea59", null ],
    [ "getScreenSpaceRect", "class_ogre_1_1_scene_manager.html#ad8ff4a3af2f2e35476c1b3250788447b", null ],
    [ "createBillboardChain", "class_ogre_1_1_scene_manager.html#a3e26531b08c7b9666ef1ecbd8568bbf8", null ],
    [ "createBillboardChain", "class_ogre_1_1_scene_manager.html#a0612e86af9d01cdbba02a32ade408892", null ],
    [ "getBillboardChain", "class_ogre_1_1_scene_manager.html#a56487d9e9eed75314b5e4a10af78d487", null ],
    [ "hasBillboardChain", "class_ogre_1_1_scene_manager.html#aea949bdea7d1547fe4316af3579b836e", null ],
    [ "destroyBillboardChain", "class_ogre_1_1_scene_manager.html#a150521e89d9f88815f42dda42f8d0bf5", null ],
    [ "destroyBillboardChain", "class_ogre_1_1_scene_manager.html#a79dcd5f1790076ec46cf1e400ea906e4", null ],
    [ "destroyAllBillboardChains", "class_ogre_1_1_scene_manager.html#aef6a32233813f424dcc1803167fa8d8c", null ],
    [ "createRibbonTrail", "class_ogre_1_1_scene_manager.html#a4d94f9a8c710929d53faa1d76c8e5a96", null ],
    [ "createRibbonTrail", "class_ogre_1_1_scene_manager.html#afe9440db228af3fdc39d4fd4d96a0935", null ],
    [ "getRibbonTrail", "class_ogre_1_1_scene_manager.html#a3dc5ca4881c431f6de9b0a6aaf0bbb31", null ],
    [ "hasRibbonTrail", "class_ogre_1_1_scene_manager.html#aec115af3cb3741397c4bdbf468cb010b", null ],
    [ "destroyRibbonTrail", "class_ogre_1_1_scene_manager.html#acd6f404670e62d2489052b574453f910", null ],
    [ "destroyRibbonTrail", "class_ogre_1_1_scene_manager.html#a58e3a4d5853bfa8a182cbc487c6f61e6", null ],
    [ "destroyAllRibbonTrails", "class_ogre_1_1_scene_manager.html#a2ec74da408f8eb47a84eb0a35f21450d", null ],
    [ "createParticleSystem", "class_ogre_1_1_scene_manager.html#a076a56f30123f94acbd269d0d67e03c4", null ],
    [ "createParticleSystem", "class_ogre_1_1_scene_manager.html#a552b50df0af56788957bd6a2650c58e3", null ],
    [ "createParticleSystem", "class_ogre_1_1_scene_manager.html#aad88733248aafaec3c399e3fb3b69628", null ],
    [ "getParticleSystem", "class_ogre_1_1_scene_manager.html#ae7fcb66c02d4f364f9e4b0fd9a2673dd", null ],
    [ "hasParticleSystem", "class_ogre_1_1_scene_manager.html#a3ff36a4579bde7a0406752c7b64c89b9", null ],
    [ "destroyParticleSystem", "class_ogre_1_1_scene_manager.html#a8ff7f09f3bc6a63e9c515187d3630733", null ],
    [ "destroyParticleSystem", "class_ogre_1_1_scene_manager.html#a157f843d13aa623897c7c211177f8f3e", null ],
    [ "destroyAllParticleSystems", "class_ogre_1_1_scene_manager.html#afce67977a494e9d9314530c0edeb18eb", null ],
    [ "clearScene", "class_ogre_1_1_scene_manager.html#aa5b2047b5740b691b0e636d57f2dba7e", null ],
    [ "setAmbientLight", "class_ogre_1_1_scene_manager.html#a7c26cdbb5703cf10a99add1f6a930ca2", null ],
    [ "getAmbientLight", "class_ogre_1_1_scene_manager.html#abf014f30f705e1d865c6c36ab40a3bfb", null ],
    [ "setWorldGeometry", "class_ogre_1_1_scene_manager.html#accb0fdfbd1f61aa4d3d6e1f4625e1f9c", null ],
    [ "setWorldGeometry", "class_ogre_1_1_scene_manager.html#a9b7ebcecf64452f59211f45d4ec33576", null ],
    [ "estimateWorldGeometry", "class_ogre_1_1_scene_manager.html#a1257fd328d54908eeb45398b3191f92b", null ],
    [ "estimateWorldGeometry", "class_ogre_1_1_scene_manager.html#abdf303a6b80c95fabfae679f0a9898f7", null ],
    [ "getSuggestedViewpoint", "class_ogre_1_1_scene_manager.html#add6fe27d7a9500aafbe9325c21985801", null ],
    [ "setOption", "class_ogre_1_1_scene_manager.html#a34f3ddda75dcf75d5c5176446b3316a8", null ],
    [ "getOption", "class_ogre_1_1_scene_manager.html#a2ea53a860f373185f5a46239f579a361", null ],
    [ "hasOption", "class_ogre_1_1_scene_manager.html#a6c9731d50869bd17fd55dfbf0f54db78", null ],
    [ "getOptionValues", "class_ogre_1_1_scene_manager.html#ae291393bc0c5bd48a8c6e79742180c93", null ],
    [ "getOptionKeys", "class_ogre_1_1_scene_manager.html#a7c8ff6b5c19eb9eeef9d5a6c9fca9fe8", null ],
    [ "_updateSceneGraph", "class_ogre_1_1_scene_manager.html#a24ad98304368771d852a5ef62eb8d277", null ],
    [ "_findVisibleObjects", "class_ogre_1_1_scene_manager.html#abd51f4629d00ff23f5064c0d2ab37647", null ],
    [ "_issueRenderOp", "class_ogre_1_1_scene_manager.html#a9e1b6ae2ee342000f96a842a164ddfe2", null ],
    [ "_renderVisibleObjects", "class_ogre_1_1_scene_manager.html#a3dce9a03ecad77d52ed0a8ef0e8b742c", null ],
    [ "_renderScene", "class_ogre_1_1_scene_manager.html#a70f86c8feca6c2b5cf140df244cf8ac5", null ],
    [ "_setDestinationRenderSystem", "class_ogre_1_1_scene_manager.html#ae87a0ee032dd09c82fa13e503711cc2b", null ],
    [ "_releaseManualHardwareResources", "class_ogre_1_1_scene_manager.html#a6a518d9bb5e39500df870f538be7a939", null ],
    [ "_restoreManualHardwareResources", "class_ogre_1_1_scene_manager.html#ad72c0a636bfdb7a891de44073ad26835", null ],
    [ "setSkyRenderingEnabled", "class_ogre_1_1_scene_manager.html#a851077fcf56225e174e0f0a52230061c", null ],
    [ "isSkyRenderingEnabled", "class_ogre_1_1_scene_manager.html#abf27eb2afe2ce63e21f474aaad7dac9b", null ],
    [ "getSkyNode", "class_ogre_1_1_scene_manager.html#a3385006ec7d87a733a8e7ca66491bc21", null ],
    [ "setSkyPlane", "class_ogre_1_1_scene_manager.html#aebb644c23f059b8bfa3702356d19c6be", null ],
    [ "_setSkyPlane", "class_ogre_1_1_scene_manager.html#a23a02fc191d8dacf508515c0116b45b1", null ],
    [ "setSkyPlaneEnabled", "class_ogre_1_1_scene_manager.html#a5e629af63f5f273a69aa9cf1e9bbceb7", null ],
    [ "isSkyPlaneEnabled", "class_ogre_1_1_scene_manager.html#a19e58a6ea76b7bb775358fcf01b5741a", null ],
    [ "getSkyPlaneNode", "class_ogre_1_1_scene_manager.html#a7be351186ec2cc070e74561ba7e4175f", null ],
    [ "getSkyPlaneGenParameters", "class_ogre_1_1_scene_manager.html#a33624066a0da8b548f283f983dd19575", null ],
    [ "setSkyBox", "class_ogre_1_1_scene_manager.html#a370c23fff9cc351b150632c707a46700", null ],
    [ "_setSkyBox", "class_ogre_1_1_scene_manager.html#abd6e42cd9332673bddd79f31ef423c1e", null ],
    [ "setSkyBoxEnabled", "class_ogre_1_1_scene_manager.html#a79cd2c00addb8bb51943e0080d92c633", null ],
    [ "isSkyBoxEnabled", "class_ogre_1_1_scene_manager.html#a100bac7be3a9303d09918d55199f7a5f", null ],
    [ "getSkyBoxNode", "class_ogre_1_1_scene_manager.html#ae68e31e10d39aab32b8ab96455d8adfa", null ],
    [ "getSkyBoxGenParameters", "class_ogre_1_1_scene_manager.html#a6ab80081d2ef6ccebc6bb0a39452bb01", null ],
    [ "setSkyDome", "class_ogre_1_1_scene_manager.html#ac1c49622909068c8c7551d5a896ada43", null ],
    [ "_setSkyDome", "class_ogre_1_1_scene_manager.html#ab2bd35627468a27a8e52a30cc364cc82", null ],
    [ "setSkyDomeEnabled", "class_ogre_1_1_scene_manager.html#a115c5ba0e3bb0ba7cc52f8f301c0e220", null ],
    [ "isSkyDomeEnabled", "class_ogre_1_1_scene_manager.html#abcee0ad945d2d8cfd43097ed378db8d8", null ],
    [ "getSkyDomeNode", "class_ogre_1_1_scene_manager.html#a088afab61603ceb636d0d428ef73d9ca", null ],
    [ "getSkyDomeGenParameters", "class_ogre_1_1_scene_manager.html#a45887375e05f0a6473c6265913ab9dae", null ],
    [ "setFog", "class_ogre_1_1_scene_manager.html#a4222a0689cb56011c11faa9976192f11", null ],
    [ "getFogMode", "class_ogre_1_1_scene_manager.html#aeaff7cf546903bc22c4113c1ae4a7ee4", null ],
    [ "getFogColour", "class_ogre_1_1_scene_manager.html#ae8ddefa5590c1209169e53fb6c02f29e", null ],
    [ "getFogStart", "class_ogre_1_1_scene_manager.html#aa44ff5a2d2a8985b7c6d2296e7fa5ffa", null ],
    [ "getFogEnd", "class_ogre_1_1_scene_manager.html#af54ce36272c2b70a1ceeb77ace86eb44", null ],
    [ "getFogDensity", "class_ogre_1_1_scene_manager.html#a864ef16daa56292b5e1e7661dc6f5f63", null ],
    [ "createBillboardSet", "class_ogre_1_1_scene_manager.html#ac85bcf0a78e313f723c6894efe020fe5", null ],
    [ "createBillboardSet", "class_ogre_1_1_scene_manager.html#a22c89b4d78b7795586e19196ad288862", null ],
    [ "getBillboardSet", "class_ogre_1_1_scene_manager.html#a35254a45a550df42861ff18f6d1a3e10", null ],
    [ "hasBillboardSet", "class_ogre_1_1_scene_manager.html#a603589528618542a181314d90cb01985", null ],
    [ "destroyBillboardSet", "class_ogre_1_1_scene_manager.html#ac69e61ce120fc3912e0abe824555928e", null ],
    [ "destroyBillboardSet", "class_ogre_1_1_scene_manager.html#a372aa23ce7f0d6c29b32e718f51b595c", null ],
    [ "destroyAllBillboardSets", "class_ogre_1_1_scene_manager.html#aa316e7d1a4d80e75940246ccb260bcca", null ],
    [ "_applySceneAnimations", "class_ogre_1_1_scene_manager.html#ab8ebc8d2fdc6798152ac6a31282de210", null ],
    [ "createAnimation", "class_ogre_1_1_scene_manager.html#aad530a7588b2544eba74370c041dfbe5", null ],
    [ "getAnimation", "class_ogre_1_1_scene_manager.html#a00b1fef15425cbcaede60137f78f2e4d", null ],
    [ "hasAnimation", "class_ogre_1_1_scene_manager.html#a0f2337636c29427cdd711b51aa29eb71", null ],
    [ "getNumAnimations", "class_ogre_1_1_scene_manager.html#afaba8c61edcedd1214b8b25e0ad178e4", null ],
    [ "getAnimation", "class_ogre_1_1_scene_manager.html#a7b33443d4ec80ecba17eba8dab4491a2", null ],
    [ "removeAnimation", "class_ogre_1_1_scene_manager.html#a87bb32dcfef86f5d04495ead956ad7e4", null ],
    [ "destroyAnimation", "class_ogre_1_1_scene_manager.html#a863ba56ae571446bb0807aa7e7204d1d", null ],
    [ "destroyAllAnimations", "class_ogre_1_1_scene_manager.html#aac4d1620c2d2d9ab5c78a3730eabc180", null ],
    [ "createAnimationState", "class_ogre_1_1_scene_manager.html#a53d1cf1fd4f032a10b4672f288322ddf", null ],
    [ "getAnimationState", "class_ogre_1_1_scene_manager.html#ae8c44578c47edd67c1c203420fa3d912", null ],
    [ "hasAnimationState", "class_ogre_1_1_scene_manager.html#a98bcdc55bd7cd845abf297100d3842a8", null ],
    [ "destroyAnimationState", "class_ogre_1_1_scene_manager.html#a2a86925fa4cbbb667f29473d5fd4a4c2", null ],
    [ "destroyAllAnimationStates", "class_ogre_1_1_scene_manager.html#a13166286851922c7af44bdf161bd682f", null ],
    [ "getAnimationIterator", "class_ogre_1_1_scene_manager.html#ab28450738168fe330709ad0d090df6b5", null ],
    [ "getAnimations", "class_ogre_1_1_scene_manager.html#a8c46aaf43efdf676ea590bbec79b514c", null ],
    [ "getAnimationStateIterator", "class_ogre_1_1_scene_manager.html#a39bf64e686d94b6856d3ff06d627b61c", null ],
    [ "getAnimationStates", "class_ogre_1_1_scene_manager.html#a7fc3ad85f4ca3e3a07b0c94950debeec", null ],
    [ "manualRender", "class_ogre_1_1_scene_manager.html#ad06375ecf563881d80eda76e06ff47c5", null ],
    [ "manualRender", "class_ogre_1_1_scene_manager.html#a80690a9450039852c9dc56a07688eb8b", null ],
    [ "getRenderQueue", "class_ogre_1_1_scene_manager.html#ada8aa825f1438e92547aa6b37fa566e8", null ],
    [ "addRenderQueueListener", "class_ogre_1_1_scene_manager.html#acc3d04347b15d26861cb566f71a46685", null ],
    [ "removeRenderQueueListener", "class_ogre_1_1_scene_manager.html#acc59696084663753264961be535d20ba", null ],
    [ "addRenderObjectListener", "class_ogre_1_1_scene_manager.html#a97f0a2a4c7992b7c37f704483f3a9166", null ],
    [ "removeRenderObjectListener", "class_ogre_1_1_scene_manager.html#a6b0c0c61aa2a3cc3022abea25c8ce5f9", null ],
    [ "addSpecialCaseRenderQueue", "class_ogre_1_1_scene_manager.html#a35ee911c94feb9c384dd34bd3bda93d9", null ],
    [ "removeSpecialCaseRenderQueue", "class_ogre_1_1_scene_manager.html#ad4f344244581a9f727c80a8aa2409283", null ],
    [ "clearSpecialCaseRenderQueues", "class_ogre_1_1_scene_manager.html#aaf563008369ba9853dd3b862ab2cb0ab", null ],
    [ "setSpecialCaseRenderQueueMode", "class_ogre_1_1_scene_manager.html#af1ff02f94ffe6e128f9e9b179737c652", null ],
    [ "getSpecialCaseRenderQueueMode", "class_ogre_1_1_scene_manager.html#a24754c64740724fbbe901b0455d02639", null ],
    [ "isRenderQueueToBeProcessed", "class_ogre_1_1_scene_manager.html#a35f9c0406735f847c0588c7ce90a7e4c", null ],
    [ "setWorldGeometryRenderQueue", "class_ogre_1_1_scene_manager.html#acbc110b48a9c3a45f55a9c6d700fe847", null ],
    [ "getWorldGeometryRenderQueue", "class_ogre_1_1_scene_manager.html#aba681db2b43ff006c48da59583b176df", null ],
    [ "_notifyAutotrackingSceneNode", "class_ogre_1_1_scene_manager.html#a436a99beba747d203841471d90e5be2e", null ],
    [ "createAABBQuery", "class_ogre_1_1_scene_manager.html#ae31e995656c34fdaa1c238efd65960b8", null ],
    [ "createSphereQuery", "class_ogre_1_1_scene_manager.html#a1859cb2e44f6d1423b263d3c34a69e6a", null ],
    [ "createPlaneBoundedVolumeQuery", "class_ogre_1_1_scene_manager.html#a06dee23e40ceefdf6f1ae8da40f8f3ca", null ],
    [ "createRayQuery", "class_ogre_1_1_scene_manager.html#a72e8efd88543fbc1c5ef1ce91b2cbd8a", null ],
    [ "createIntersectionQuery", "class_ogre_1_1_scene_manager.html#a7c07a1ff3d2484281de15d6cae6777f7", null ],
    [ "destroyQuery", "class_ogre_1_1_scene_manager.html#aa4e86291c054d59c1312c10322e6bc55", null ],
    [ "setShadowTechnique", "class_ogre_1_1_scene_manager.html#ad716d3752418408f073d9be9bbfe62d0", null ],
    [ "getShadowTechnique", "class_ogre_1_1_scene_manager.html#a65a4957bcb2a0fbffcb8ef37c1f6c6b1", null ],
    [ "setShadowColour", "class_ogre_1_1_scene_manager.html#a81238e49e69e53ccbc650413410f3f92", null ],
    [ "getShadowColour", "class_ogre_1_1_scene_manager.html#a7b12c8a965b7dd03f6b07d8acfa74079", null ],
    [ "setShadowDirectionalLightExtrusionDistance", "class_ogre_1_1_scene_manager.html#a69d6cb870736cd52b9ca48986e2e442b", null ],
    [ "getShadowDirectionalLightExtrusionDistance", "class_ogre_1_1_scene_manager.html#a95ae7048e7f5d3ffabf6d8acbcf12a0d", null ],
    [ "isShadowTechniqueStencilBased", "class_ogre_1_1_scene_manager.html#ab394162f7351f8701df5a8fee182f7e6", null ],
    [ "isShadowTechniqueTextureBased", "class_ogre_1_1_scene_manager.html#af1a5829a519ed4c752abd7619685d67b", null ],
    [ "isShadowTechniqueModulative", "class_ogre_1_1_scene_manager.html#a9d64b8d561a3d6d7886a62209c834065", null ],
    [ "isShadowTechniqueAdditive", "class_ogre_1_1_scene_manager.html#a181ab08e5363f7d00053eac122ade55b", null ],
    [ "isShadowTechniqueIntegrated", "class_ogre_1_1_scene_manager.html#a8af3e6766eb128c8a8c02aab822e87fc", null ],
    [ "isShadowTechniqueInUse", "class_ogre_1_1_scene_manager.html#a22b489f7b4262b530c35435527ca11ea", null ],
    [ "setShowDebugShadows", "class_ogre_1_1_scene_manager.html#af5efe579331ee28f3cbe3919db52751f", null ],
    [ "getShowDebugShadows", "class_ogre_1_1_scene_manager.html#a9d05b4611701aac416246a876d29c740", null ],
    [ "setShadowIndexBufferSize", "class_ogre_1_1_scene_manager.html#a39c2c5902cd0eb7e86f272ed421cb408", null ],
    [ "getShadowIndexBufferSize", "class_ogre_1_1_scene_manager.html#a5dce576ae8d38b4ed712991115cf1067", null ],
    [ "setShadowUseInfiniteFarPlane", "class_ogre_1_1_scene_manager.html#add6959f7447251600bd189008636e887", null ],
    [ "setShadowUseLightClipPlanes", "class_ogre_1_1_scene_manager.html#a40f296de8599657b70b7072921cbaa16", null ],
    [ "getShadowUseLightClipPlanes", "class_ogre_1_1_scene_manager.html#a2b4a3f7bbd31ecd067ae017e6571da1b", null ],
    [ "setShadowFarDistance", "class_ogre_1_1_scene_manager.html#a103f475cd458b8bbdbf5ff679eeb20a8", null ],
    [ "getShadowFarDistance", "class_ogre_1_1_scene_manager.html#abd8b3284334279f65fa12b5ff2571eca", null ],
    [ "getShadowFarDistanceSquared", "class_ogre_1_1_scene_manager.html#abe1ca9b5f8ea5a7256b1d0ca1a2d8f6c", null ],
    [ "prepareShadowTextures", "class_ogre_1_1_scene_manager.html#a95cd8ff86a7178c2e37b2fcb485f64fa", null ],
    [ "setShadowTextureSize", "class_ogre_1_1_scene_manager.html#aa55e7f4482a2860c6378d97d8b5dfb57", null ],
    [ "setShadowTextureConfig", "class_ogre_1_1_scene_manager.html#adcbf0f49de53a7b67574481703d4fc03", null ],
    [ "setShadowTextureConfig", "class_ogre_1_1_scene_manager.html#a5e3389a02ae12fc67f999bf16495010b", null ],
    [ "getShadowTextureConfigList", "class_ogre_1_1_scene_manager.html#a7a825394e34b46ac32c89ca6ed97d49e", null ],
    [ "getShadowTextureConfigIterator", "class_ogre_1_1_scene_manager.html#aeca662aaa6dc25f7115ef1c675e34485", null ],
    [ "setShadowTexturePixelFormat", "class_ogre_1_1_scene_manager.html#a3f2c4ffe2ab173848c0cff67789d530e", null ],
    [ "setShadowTextureFSAA", "class_ogre_1_1_scene_manager.html#af32fab74832905ca7c206f81c88f24fa", null ],
    [ "setShadowTextureCount", "class_ogre_1_1_scene_manager.html#a85c3a0d9755dfdfa841ec1383b20687c", null ],
    [ "getShadowTextureCount", "class_ogre_1_1_scene_manager.html#a2b993e97d08dd4534ce1288c8de183e0", null ],
    [ "setShadowTextureCountPerLightType", "class_ogre_1_1_scene_manager.html#a70f8eddf9b8617783fb7d0995b985a9a", null ],
    [ "getShadowTextureCountPerLightType", "class_ogre_1_1_scene_manager.html#af6c350b864e2bca3132abfd05b9a4b5e", null ],
    [ "setShadowTextureSettings", "class_ogre_1_1_scene_manager.html#a6efbc50e4ab15a4436cac712e049e79e", null ],
    [ "setShadowTextureCompositor", "class_ogre_1_1_scene_manager.html#a42817122ac0cbd7e3d95305681e661f0", null ],
    [ "getShadowTexture", "class_ogre_1_1_scene_manager.html#a3cd9f9a98d1daff0c440c54e3082bedc", null ],
    [ "setShadowDirLightTextureOffset", "class_ogre_1_1_scene_manager.html#a3596ae101fe86d686cc67e9b3aad58cb", null ],
    [ "getShadowDirLightTextureOffset", "class_ogre_1_1_scene_manager.html#a43c5ca986d31852a89c6e2d06a025ee3", null ],
    [ "setShadowTextureFadeStart", "class_ogre_1_1_scene_manager.html#a25f052046f0d421ac78a89730fd766e1", null ],
    [ "setShadowTextureFadeEnd", "class_ogre_1_1_scene_manager.html#a4e166fc972e614490ab6164eda2be0e5", null ],
    [ "setShadowTextureSelfShadow", "class_ogre_1_1_scene_manager.html#a1963d4af77db29c6419737c1c1ee9a31", null ],
    [ "getShadowTextureSelfShadow", "class_ogre_1_1_scene_manager.html#a2ac8cbf2f621bc71f97d0bdffdf45259", null ],
    [ "setShadowTextureCasterMaterial", "class_ogre_1_1_scene_manager.html#aa22c0af6835b4a0524b4122756cdd93c", null ],
    [ "setShadowTextureReceiverMaterial", "class_ogre_1_1_scene_manager.html#a69310c322ea5f58d9c38c13a971f8125", null ],
    [ "setShadowCasterRenderBackFaces", "class_ogre_1_1_scene_manager.html#a9b4c5bd6f47373ca69a397edb49f3520", null ],
    [ "getShadowCasterRenderBackFaces", "class_ogre_1_1_scene_manager.html#a89d5a39615a8edb5923cef433aba210d", null ],
    [ "setShadowCameraSetup", "class_ogre_1_1_scene_manager.html#acd2de135b378c048c4c4a2dff4c73ac8", null ],
    [ "getShadowCameraSetup", "class_ogre_1_1_scene_manager.html#aa26b5c8c1d5094b5a09f1794dc834caf", null ],
    [ "_setActiveCompositorChain", "class_ogre_1_1_scene_manager.html#a9a5c7191febaebc65eb605202c0062cb", null ],
    [ "setLateMaterialResolving", "class_ogre_1_1_scene_manager.html#a974ac50bee0284e4bf69dcffa836c11f", null ],
    [ "isLateMaterialResolving", "class_ogre_1_1_scene_manager.html#ab7f2ff2c074c944a8fca85bc9ef0e8b8", null ],
    [ "_getActiveCompositorChain", "class_ogre_1_1_scene_manager.html#a13c902b471e9b7cbbb088ec4528be1c2", null ],
    [ "addListener", "class_ogre_1_1_scene_manager.html#a8d613edec86ef5bc9e4f36b8be47bd92", null ],
    [ "removeListener", "class_ogre_1_1_scene_manager.html#a8cc2d2f9cee748c6f1c3ade359a35b7b", null ],
    [ "addShadowTextureListener", "class_ogre_1_1_scene_manager.html#aff2097540f9f80235394436b3178a159", null ],
    [ "removeShadowTextureListener", "class_ogre_1_1_scene_manager.html#a13cfa26dbe9b7c651ddd67f948ef7acd", null ],
    [ "createStaticGeometry", "class_ogre_1_1_scene_manager.html#a89f2ca5ef5c9ba9856fdfcd0fadb0742", null ],
    [ "getStaticGeometry", "class_ogre_1_1_scene_manager.html#adb484fdb3b987874a0396c78e3a0a801", null ],
    [ "hasStaticGeometry", "class_ogre_1_1_scene_manager.html#acaf0c820efd7c9870d0630faea7013fa", null ],
    [ "getStaticGeometryCollection", "class_ogre_1_1_scene_manager.html#a9c2c49f7ecf09c146944d37727d58a2e", null ],
    [ "destroyStaticGeometry", "class_ogre_1_1_scene_manager.html#af5bab37a967b021bb03c3c5d840b56ea", null ],
    [ "destroyStaticGeometry", "class_ogre_1_1_scene_manager.html#ac83d27698223cffeeafd19a9146f51f6", null ],
    [ "destroyAllStaticGeometry", "class_ogre_1_1_scene_manager.html#a5680c250fb35ab999e0d5d10b597216b", null ],
    [ "createInstanceManager", "class_ogre_1_1_scene_manager.html#a5579128d01a04448a96d6a2acc663a45", null ],
    [ "getInstanceManager", "class_ogre_1_1_scene_manager.html#a92949801ae19aa32c11329e43ad32555", null ],
    [ "hasInstanceManager", "class_ogre_1_1_scene_manager.html#ab0cfa0bac914e025fbf2ed64f6b6ef5d", null ],
    [ "destroyInstanceManager", "class_ogre_1_1_scene_manager.html#a5004093c72a34c3d50f17c754a4dd572", null ],
    [ "destroyInstanceManager", "class_ogre_1_1_scene_manager.html#ad1108eb8e2a42a2c91b4f7473f202b50", null ],
    [ "destroyAllInstanceManagers", "class_ogre_1_1_scene_manager.html#a99397cd65e23402e63966ff006f1ed6e", null ],
    [ "getNumInstancesPerBatch", "class_ogre_1_1_scene_manager.html#a5fcc14bc6160a096212b08136fd18bc0", null ],
    [ "createInstancedEntity", "class_ogre_1_1_scene_manager.html#ab5ca78b75ee852011cb0c079ac11f67b", null ],
    [ "destroyInstancedEntity", "class_ogre_1_1_scene_manager.html#a3c11f4546d5bcad35fa37ad778bb5cbe", null ],
    [ "_addDirtyInstanceManager", "class_ogre_1_1_scene_manager.html#a8cd474a0bb93c6fa0e4439a5a7d11c63", null ],
    [ "createMovableObject", "class_ogre_1_1_scene_manager.html#a27e6bc1d92f3c7438972e1ad137edfb6", null ],
    [ "createMovableObject", "class_ogre_1_1_scene_manager.html#aa1298c907d72f01f3510876d4597ed37", null ],
    [ "destroyMovableObject", "class_ogre_1_1_scene_manager.html#a0e7f50ed2e09149b057a7d09fc127403", null ],
    [ "destroyMovableObject", "class_ogre_1_1_scene_manager.html#a9226149b4f9745ff57f978014a9fda48", null ],
    [ "destroyAllMovableObjectsByType", "class_ogre_1_1_scene_manager.html#a093f1ffd9658098d388aa3a847338f91", null ],
    [ "destroyAllMovableObjects", "class_ogre_1_1_scene_manager.html#aa15b95a642dd9553498cba260ca160d8", null ],
    [ "getMovableObject", "class_ogre_1_1_scene_manager.html#a95b8dfba2dd4ed9b62dfef6fb6baf2b7", null ],
    [ "hasMovableObject", "class_ogre_1_1_scene_manager.html#a7179987953e8b7889610ab469637bd93", null ],
    [ "getMovableObjects", "class_ogre_1_1_scene_manager.html#a572ba24b3243aafc7ccc74598b018eeb", null ],
    [ "getMovableObjectIterator", "class_ogre_1_1_scene_manager.html#a09e912c708107f9432565bff39ba4b63", null ],
    [ "injectMovableObject", "class_ogre_1_1_scene_manager.html#a1eaa9f147fe2c97f159ffa1896a1be88", null ],
    [ "extractMovableObject", "class_ogre_1_1_scene_manager.html#a326e7192cb5d4cc36c035f1a1dfa01a5", null ],
    [ "extractMovableObject", "class_ogre_1_1_scene_manager.html#a92b9b85e83300438d40feed407285207", null ],
    [ "extractAllMovableObjectsByType", "class_ogre_1_1_scene_manager.html#a2d3831103729210e5ddd4e4e82c6044e", null ],
    [ "setVisibilityMask", "class_ogre_1_1_scene_manager.html#a66125a97e2d4722031dd636f7229569c", null ],
    [ "getVisibilityMask", "class_ogre_1_1_scene_manager.html#a97a7f01d29c2eabe0843d966ab9601e3", null ],
    [ "_getCombinedVisibilityMask", "class_ogre_1_1_scene_manager.html#a981ad410d5a077bb64938685e10fcee0", null ],
    [ "setFindVisibleObjects", "class_ogre_1_1_scene_manager.html#ab0a1beb3ad46d39d89d0338f2ec21558", null ],
    [ "getFindVisibleObjects", "class_ogre_1_1_scene_manager.html#a82ee334ba3818ff766463a74bfbf985c", null ],
    [ "setFlipCullingOnNegativeScale", "class_ogre_1_1_scene_manager.html#ae7115dce2e4a2c2dc49b0996b9279a21", null ],
    [ "getFlipCullingOnNegativeScale", "class_ogre_1_1_scene_manager.html#a15ff1cbfaa46b4c8786b80bcc7212488", null ],
    [ "_injectRenderWithPass", "class_ogre_1_1_scene_manager.html#a1593fab748d1b0820e93e49d5732350b", null ],
    [ "_setPass", "class_ogre_1_1_scene_manager.html#a26901bfac04ed8a47ef92e3437f0e28d", null ],
    [ "_markGpuParamsDirty", "class_ogre_1_1_scene_manager.html#a9f1d305989a47813acb2300c208ce603", null ],
    [ "_renderQueueGroupObjects", "class_ogre_1_1_scene_manager.html#a6336349899e883a51d7446ef4cc3d9df", null ],
    [ "setQueuedRenderableVisitor", "class_ogre_1_1_scene_manager.html#af55b7d8cf3daf68db0266139faf73492", null ],
    [ "getQueuedRenderableVisitor", "class_ogre_1_1_scene_manager.html#afc225e6c4de27fec3855c725cef29b06", null ],
    [ "getDestinationRenderSystem", "class_ogre_1_1_scene_manager.html#a91dee910ef9412d09800e11b4c5f569c", null ],
    [ "getCurrentViewport", "class_ogre_1_1_scene_manager.html#af6005796f7680faa75d9452bcc93bf8b", null ],
    [ "getVisibleObjectsBoundsInfo", "class_ogre_1_1_scene_manager.html#a4893a4c8bb8dac7b40733a3a440cd806", null ],
    [ "getShadowCasterBoundsInfo", "class_ogre_1_1_scene_manager.html#a91a7ddeaa86b14ea4da9b33fad388ea8", null ],
    [ "addLodListener", "class_ogre_1_1_scene_manager.html#a2ac761cb112de51be26c54609de3c83a", null ],
    [ "removeLodListener", "class_ogre_1_1_scene_manager.html#a25cc1bb36997b722fc60efc7903f3760", null ],
    [ "_notifyMovableObjectLodChanged", "class_ogre_1_1_scene_manager.html#ae4b6a7748dc4273fd6c160fb162c544f", null ],
    [ "_notifyEntityMeshLodChanged", "class_ogre_1_1_scene_manager.html#ad0a84e6426cad7dfd721fb5fccd9976c", null ],
    [ "_notifyEntityMaterialLodChanged", "class_ogre_1_1_scene_manager.html#a272d1a76e7854e51f824f0099a4910cf", null ],
    [ "_handleLodEvents", "class_ogre_1_1_scene_manager.html#a72e39912a34617ffa0455f859ec438c3", null ],
    [ "_getCurrentRenderStage", "class_ogre_1_1_scene_manager.html#aaa36e203e1ba3eeab880e4c51a51efae", null ],
    [ "_getAutoParamDataSource", "class_ogre_1_1_scene_manager.html#aaa72eaf9861531687d7bb2a4cc989f42", null ],
    [ "setVPRTCameras", "class_ogre_1_1_scene_manager.html#afcc3ad744c0bd91c63db369a70141482", null ],
    [ "SceneMgrQueuedRenderableVisitor", "class_ogre_1_1_scene_manager.html#a25811fa0c23672b27dccfffd48bec43a", null ],
    [ "PT_PLANE", "class_ogre_1_1_scene_manager.html#aba1522f277022ea928223ef9bb8f2806", null ],
    [ "PT_CUBE", "class_ogre_1_1_scene_manager.html#aeefb47c4d2f8b961381e9b25ab31c22d", null ],
    [ "PT_SPHERE", "class_ogre_1_1_scene_manager.html#aa0adfbc6f313be8895a9f38872c76eaf", null ]
];